@@ -202,6 +202,22 @@ def setPluginEnabled(pluginFolder, pluginElement, enable, hubName = ""):
 	data = (enable, pluginFolder, pluginElement)
 	db.query_rowcount(sql, data)	
 
+def getPluginEnabled(pluginFolder, pluginElement, hubName = ""):
+	"""
+	Get published field for the given plugin in the jos_plugins table
+	"""
+	
+	# database config
+	dbPW = getWebConfigDBPassword(hubName)
+	dbUserName = getWebConfigDBUsername(hubName)
+	dbName = getWebConfigDBName(hubName)	
+	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+		
+	sql = "SELECT published FROM jos_plugins WHERE `folder` = %s AND `element` = %s"
+	data = (pluginFolder, pluginElement)
+	published = db.query_selectscalar(sql, data)
+	return published
+
 
 def getHubSiteConfig(hubname, sectionName, valueName):
 	"""
