@@ -31,6 +31,7 @@ import contextlib
 import exceptions
 import itertools
 import sys
+import warnings
 
 # Guess there is a chance this won't be installed
 try:
@@ -39,6 +40,7 @@ except ImportError:
 	sys.stderr.write("Error: Cannot import MySQLdb library")
 	sys.exit(1)
 
+warnings.filterwarnings('error', category=MySQLdb.Warning)
 
 class MySQLConnection:
 	""" Very lightweight MySQL library """
