@@ -408,7 +408,7 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 			data = (dgroup.cn)
 			
 			for userGroupMembership in db.query(sql, data):
-				groupMembers.append(str(userGroupMembership.uidNumber))
+				groupMembers.append(str(userGroupMembership.username))
 
 		try:
 			print "syncing group '" + dgroup.cn + "' to ldap"
